==> tentackle-sql-2.1.2-sources.jar: org/tentackle/sql/DefaultBackendFactory.java <==
/**
 * Tentackle - http://www.tentackle.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


package org.tentackle.sql;

import java.util.ArrayList;
import java.util.Collection;
import org.tentackle.common.Service;
import org.tentackle.common.ServiceFactory;

/**
 * Default implementation of a backend factory.
 *
 * @author harald
 */
@Service(BackendFactory.class)
public class DefaultBackendFactory implements BackendFactory {


  /**
   * All backend singletons.
   * One per backend type.
   */
  private final Collection<Backend> backends;


  /**
   * Creates a backend factory.<br>
   * Collects all Backend services.
   */
  public DefaultBackendFactory() {
    backends = new ArrayList<>();
    try {
      for (Class<Backend> backendClass: ServiceFactory.getServiceFinder().findServiceProviders(Backend.class)) {
        backends.add(backendClass.newInstance());
      }
    }
    catch (ClassNotFoundException | InstantiationException | IllegalAccessException nfe) {
      throw new BackendException("supported backends could not be determined", nfe);
    }
  }


  @Override
  public Backend getBackendByUrl(String url) {
    for (Backend backend: backends) {
      if (backend.isMatchingUrl(url)) {
        return backend;
      }
    }
    throw new BackendException("no backend for jdbc-url=" + url);
  }

  @Override
  public Backend getBackendByName(String name) throws BackendException {
    for (Backend backend: backends) {
      if (backend.isMatchingName(name)) {
        return backend;
      }
    }
    throw new BackendException("no backend for name=" + name);
  }

  @Override
  public Collection<Backend> getAllBackends() throws BackendException {
    return backends;
  }

}

==> tentackle-sql-11.7.4.1-sources.jar: org/tentackle/sql/DefaultBackendFactory.java <==
/*
 * Tentackle - https://tentackle.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


package org.tentackle.sql;

import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;
import java.util.Collection;
import org.tentackle.common.Service;
import org.tentackle.common.ServiceFactory;

/**
 * Default implementation of a backend factory.
 *
 * @author harald
 */
@Service(BackendFactory.class)
public class DefaultBackendFactory implements BackendFactory {


  /**
   * All backend singletons.
   * One per backend type.
   */
  private final Collection<Backend> backends;


  /**
   * Creates a backend factory.<br>
   * Collects all Backend services.
   */
  public DefaultBackendFactory() {
    backends = new ArrayList<>();
    try {
      for (Class<Backend> backendClass: ServiceFactory.getServiceFinder().findServiceProviders(Backend.class)) {
        backends.add(backendClass.getDeclaredConstructor().newInstance());
      }
    }
    catch (ClassNotFoundException | InstantiationException | IllegalAccessException |
           InvocationTargetException | NoSuchMethodException nfe) {
      throw new BackendException("supported backends could not be determined", nfe);
    }
  }


  @Override
  public Backend getBackendByUrl(String url) {
    for (Backend backend: backends) {
      if (backend.isMatchingUrl(url)) {
        return backend;
      }
    }
    throw new BackendException("no backend for jdbc-url=" + url);
  }

  @Override
  public Backend getBackendByName(String name) {
    for (Backend backend: backends) {
      if (backend.isMatchingName(name)) {
        return backend;
      }
    }
    throw new BackendException("no backend for name=" + name);
  }

  @Override
  public Collection<Backend> getAllBackends() {
    return backends;
  }

}
